@@ -173,6 +173,9 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_SMSListID:
                 f = Py_BuildValue("{s:s,s:O}", "Type", "SMSListID", "Value", PyLong_FromUnsignedLong(entry->Entries[i].Number));
                 break;
+            case PBK_CallLength:
+                f = Py_BuildValue("{s:s,s:i}", "Type", "CallLength", "Value", entry->Entries[i].CallLength);
+                break;
         }
 
         if (f == Py_None) {
@@ -381,6 +384,9 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("SMSListID", type) == 0) {
             valuetype = 'n';
             entry->Entries[i].EntryType = PBK_SMSListID;
+        } else if (strcmp("CallLength", type) == 0) {
+            valuetype = 'c';
+            entry->Entries[i].EntryType = PBK_CallLength;
         } else {
             PyErr_Format(PyExc_ValueError, "Element %i in Entries has bad type: %s", i, type);
             return 0;
@@ -391,6 +397,10 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
                 entry->Entries[i].Number = GetIntFromDict(item, "Value");
                 if (entry->Entries[i].Number == INT_INVALID) return 0;
                 break;
+            case 'c':
+                entry->Entries[i].CallLength = GetIntFromDict(item, "Value");
+                if (entry->Entries[i].CallLength == INT_INVALID) return 0;
+                break;
             case 't':
                 if (!CopyStringFromDict(item, "Value", GSM_PHONEBOOK_TEXT_LENGTH, entry->Entries[i].Text))
                     return 0;
